@@ -8,12 +8,6 @@ pub mod binance;
 /// Bitstamp WebSocket client implementing the ExchangeClient trait.
 pub mod bitstamp;
 
-/// Common client configuration that is likely required by an ExchangeClient trait implementor.
-#[derive(Debug, Deserialize)]
-pub struct ClientConfig {
-    pub rate_limit_per_minute: u64,
-}
-
 /// Possible exchange Client names.
 #[derive(Debug, Deserialize, Serialize, PartialOrd, PartialEq, Clone)]
 pub enum ClientName {
