@@ -1,7 +1,6 @@
 use crate::error::ClientError;
 use crate::{Identifier, StreamIdentifier, Subscription, WSStream};
 use futures_util::SinkExt;
-use log::{debug, error, info, warn};
 use serde::de::DeserializeOwned;
 use serde::Serialize;
 use std::collections::HashMap;
@@ -9,6 +8,7 @@ use std::fmt::Debug;
 use tokio::sync::mpsc;
 use tokio_stream::StreamExt;
 use tokio_tungstenite::tungstenite::Message as WSMessage;
+use tracing::{debug, error, info, warn};
 
 /// Type alias to communicate a stream's unique String identifier that can be used to route messages
 /// from the [ConnectionHandler] to the relevant downstream consumer.
@@ -208,52 +208,6 @@ mod tests {
         BinanceSub::new("@depth20@100ms".to_string(), "ethbtc".to_string())
     }
 
-    // Bitstamp Connection & Subscription
-    // async fn gen_bitstamp_conn() -> WSStream {
-    //     connect(&String::from("wss://ws.bitstamp.net/"))
-    //         .await
-    //         .unwrap()
-    // }
-    // fn gen_valid_bitstamp_sub() -> BitstampSub {
-    //     BitstampSub::new("order_book_".to_string(), "ethbtc".to_string())
-    // }
-
-    #[tokio::test]
-    async fn test_calculate_rate_limit_interval() {
-        struct TestCase {
-            input_limit_per_min: u64,
-            output_limit_duration: Duration,
-        }
-
-        let test_cases = vec![
-            TestCase {
-                // Test case 0:
-                input_limit_per_min: 33,
-                output_limit_duration: Duration::from_millis(550),
-            },
-            TestCase {
-                // Test case 1:
-                input_limit_per_min: 255,
-                output_limit_duration: Duration::from_millis(4250),
-            },
-            TestCase {
-                // Test case 2:
-                input_limit_per_min: 5,
-                output_limit_duration: Duration::from_secs_f64(1.0 / 12.0),
-            },
-        ];
-
-        for (index, test) in test_cases.into_iter().enumerate() {
-            let actual_result = calculate_rate_limit_interval(test.input_limit_per_min);
-            assert_eq!(
-                test.output_limit_duration,
-                actual_result.period(),
-                "Test case: {:?}",
-                index
-            )
-        }
-    }
-
     #[tokio::test]
     async fn test_binance_subscribe() {
         struct TestCase {
@@ -262,17 +216,12 @@ mod tests {
             expected_can_subscribe: bool,
         }
 
-        let test_cases = vec![
-            TestCase {
-                // Test case 0: Valid Binance subscription
-                conn_handler: ConnectionHandler::new(
-                    gen_binance_conn().await,
-                    mpsc::channel(10).1,
-                ),
-                input_sub: gen_valid_binance_sub(),
-                expected_can_subscribe: true,
-            },
-        ];
+        let test_cases = vec![TestCase {
+            // Test case 0: Valid Binance subscription
+            conn_handler: ConnectionHandler::new(gen_binance_conn().await, mpsc::channel(10).1),
+            input_sub: gen_valid_binance_sub(),
+            expected_can_subscribe: true,
+        }];
 
         for (index, mut test) in test_cases.into_iter().enumerate() {
             let actual_result = test.conn_handler.subscribe(test.input_sub).await;
